<!DOCTYPE TS><TS>
<context>
    <name>MythNews</name>
    <message>
        <source>Updated</source>
        <translation>Actualizado</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Edit Site Details</source>
        <translation>Editar Detalles Fuente</translation>
    </message>
    <message>
        <source>Enter Site Details</source>
        <translation>Introducir Detalles Fuente</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Icono:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Edit News Site</source>
        <translation>Editar Fuente Noticias</translation>
    </message>
    <message>
        <source>Add News Site</source>
        <translation>Añadir Fuente Noticias</translation>
    </message>
    <message>
        <source>Delete News Site</source>
        <translation>Borrar Fuente Noticias</translation>
    </message>
</context>
<context>
    <name>MythNewsConfig</name>
    <message>
        <source>Press MENU to set the update frequency.</source>
        <translation>Pulse MENU para ajustar la frecuencia de actualización.</translation>
    </message>
    <message>
        <source>Set update frequency by using the up/down arrows.
The minimum allowed value is 30 Minutes.</source>
        <translation type="obsolete">Ajuste la frecuencia de actualización usando las flechas arriba/abajo.
El valor mínimo permitido es de 30 minutos.</translation>
    </message>
    <message>
        <source>Press MENU to return to feed selection.</source>
        <translation type="obsolete">Pulse MENU para volver a la selección de feeds.</translation>
    </message>
    <message>
        <source>Set update frequency by using the up/down arrows.Minimum value is 30 Minutes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press Escape or Menu to exit.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewsSite</name>
    <message>
        <source>Failed to retrieve news</source>
        <translation>Fallo al descargar noticias</translation>
    </message>
    <message>
        <source>Retrieve Failed. </source>
        <translation>Descarga fallida. </translation>
    </message>
    <message>
        <source>No Cached News</source>
        <translation>Sin noticias cacheadas</translation>
    </message>
    <message>
        <source>Failed to read downloaded file</source>
        <translation>Fallo al leer fichero descargado</translation>
    </message>
    <message>
        <source>Showing Cached News</source>
        <translation>Mostrando noticias cacheadas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>MythNews</source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this news site

%1</source>
        <translation>¿Seguro que quiere borrar esta fuente de noticias?

%1</translation>
    </message>
    <message>
        <source>Downloading media...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
</context>
</TS>
